pub struct VerifyOpts {
pub ignore_lockfile: bool,
pub no_check_feedback: bool,
pub rust_releases_opts: RustReleasesOpts,
pub rust_version: Option<BareVersion>,
pub toolchain_opts: ToolchainOpts,
pub custom_check_opts: CustomCheckOpts,
}Fields
ignore_lockfile: boolIgnore the lockfile for the MSRV search
no_check_feedback: boolDon’t print the result of compatibility checks
The feedback of a compatibility check can be useful to determine why a certain Rust version is not compatible. Rust usually prints very detailed error messages. While most often very useful, in some cases they may be too noisy or lengthy. If this flag is given, the result messages will not be printed.
rust_releases_opts: RustReleasesOptsrust_version: Option<BareVersion>The Rust version, to check against for toolchain compatibility
If not set, the MSRV will be parsed from the Cargo manifest instead.
toolchain_opts: ToolchainOptscustom_check_opts: CustomCheckOptsTrait Implementations
Sourceimpl Args for VerifyOpts
impl Args for VerifyOpts
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for VerifyOpts
impl Debug for VerifyOpts
Sourceimpl FromArgMatches for VerifyOpts
impl FromArgMatches for VerifyOpts
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for VerifyOpts
impl RefUnwindSafe for VerifyOpts
impl Send for VerifyOpts
impl Sync for VerifyOpts
impl Unpin for VerifyOpts
impl UnsafeUnpin for VerifyOpts
impl UnwindSafe for VerifyOpts