pub struct FindOpts {
pub bisect: bool,
pub linear: bool,
pub write_toolchain_file: bool,
pub ignore_lockfile: bool,
pub skip_unavailable_toolchains: bool,
pub no_check_feedback: bool,
pub write_msrv: bool,
pub rust_releases_opts: RustReleasesOpts,
pub toolchain_opts: ToolchainOpts,
pub custom_check_opts: CustomCheckOpts,
}Fields
bisect: boolUse a binary search to find the MSRV (default)
When the search space is sufficiently large, which is common, this is much faster than a linear search. A binary search will approximately halve the search space for each Rust version checked for compatibility.
linear: boolUse a linear search to find the MSRV
This method checks toolchain from the most recent release to the earliest.
write_toolchain_file: boolPin the MSRV by writing the version to a rust-toolchain file
The toolchain file will pin the Rust version for this crate.
ignore_lockfile: boolTemporarily remove the lockfile, so it will not interfere with the building process
This is important when testing against older Rust versions such as Cargo versions prior to Rust 1.38.0, for which Cargo does not recognize the newer lockfile formats.
Treats a Rust version as incompatible when a toolchain failed to install or was otherwise unavailable
Can be useful for reducing the search space on platforms with limited toolchain availability. Be warned that network errors on either end can also mark versions incorrectly as incompatible.
no_check_feedback: boolDon’t print the result of compatibility checks
The feedback of a compatibility check can be useful to determine why a certain Rust version is not compatible. Rust usually prints very detailed error messages. While most often very useful, in some cases they may be too noisy or lengthy. If this flag is given, the result messages will not be printed.
write_msrv: boolWrite the MSRV to the Cargo manifest
For toolchains which include a Cargo version which supports the rust-version field,
the package.rust-version field will be written. For older Rust toolchains,
the package.metadata.msrv field will be written instead.
rust_releases_opts: RustReleasesOptstoolchain_opts: ToolchainOptscustom_check_opts: CustomCheckOptsTrait Implementations
Sourceimpl Args for FindOpts
impl Args for FindOpts
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for FindOpts
impl FromArgMatches for FindOpts
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Auto Trait Implementations
impl Freeze for FindOpts
impl RefUnwindSafe for FindOpts
impl Send for FindOpts
impl Sync for FindOpts
impl Unpin for FindOpts
impl UnsafeUnpin for FindOpts
impl UnwindSafe for FindOpts